@@ -5,7 +5,7 @@ use warnings;
 use Config::IniFiles;
 
 use Exporter;
-our $VERSION		= 0.05;
+our $VERSION		= 0.06;
 our @ISA		= qw(Exporter);
 
 # Cration d'un dictionnaire  partir d'un fichier INI.
@@ -63,4 +63,15 @@ sub translate {
 	return $val;
 }
 
+sub substitue_char {
+	my ($self, $line) = shift;
+
+	# valeur par dfaut dans le cas o le champs serait undef
+	if (!defined($line) || length($line) == 0) {
+		$line = '';
+		return $line ;
+	}
+
+}
+
 1;
